@@ -1,6 +1,6 @@
 package Ubic::Multiservice::Dir;
 BEGIN {
-  $Ubic::Multiservice::Dir::VERSION = '1.12';
+  $Ubic::Multiservice::Dir::VERSION = '1.13';
 }
 
 use strict;
@@ -12,14 +12,13 @@ Ubic::Multiservice::Dir - multiservice which uses directory with configs to inst
 
 =head1 VERSION
 
-version 1.12
+version 1.13
 
 =cut
 
 use base qw(Ubic::Multiservice);
 use Params::Validate qw(:all);
 use Carp;
-use Perl6::Slurp;
 use File::Basename;
 use Scalar::Util qw(blessed);
 
@@ -71,7 +70,10 @@ sub simple_service($$) {
         return $service;
     }
     elsif (-e $file) {
-        my $content = slurp($file);
+        open my $fh, '<', $file or die "Can't open $file: $!";
+        my $content = do { local $/; <$fh> };
+        close $fh or die "Can't close $file: $!";
+
         $content = "# line 1 $file\n$content";
         $content = "package UbicService".($eval_id++).";\n# line 1 $file\n$content";
         my $service = eval $content;
