@@ -1,6 +1,6 @@
 package Ubic::Service::Common;
 BEGIN {
-  $Ubic::Service::Common::VERSION = '1.12';
+  $Ubic::Service::Common::VERSION = '1.13';
 }
 
 use strict;
@@ -12,7 +12,7 @@ Ubic::Service::Common - common way to construct new service by specifying severa
 
 =head1 VERSION
 
-version 1.12
+version 1.13
 
 =head1 SYNOPSIS
 
@@ -93,7 +93,8 @@ sub new {
         name        => { type => SCALAR, regex => qr/^[\w-]+$/, optional => 1 }, # violates Ubic::Service incapsulation...
         port        => { type => SCALAR, regex => qr/^\d+$/, optional => 1 },
         custom_commands => { type => HASHREF, default => {} },
-        user        => { type => SCALAR, default => 'root' },
+        user        => { type => SCALAR, optional => 1 },
+        group       => { type => SCALAR, optional => 1 },
         timeout_options => { type => HASHREF, default => {} },
     });
     if ($params->{custom_commands}) {
@@ -137,7 +138,14 @@ sub custom_commands {
 
 sub user {
     my $self = shift;
-    return $self->{user};
+    return $self->{user} if defined $self->{user};
+    return $self->SUPER::user();
+}
+
+sub group {
+    my $self = shift;
+    return $self->{group} if defined $self->{group};
+    return $self->SUPER::group();
 }
 
 sub do_custom_command {
